@@ -29,6 +29,7 @@ def show_about(app_id, version, parent):
         "Adrian Solom",
         "Alberto Fanjul",
         "Alexander Mikhaylenko",
+        "Alpesh Jamgade",
         "Andre Klapper",
         "Andreas Nilsson",
         "Apostol Bakalov",
@@ -146,7 +147,7 @@ def show_about(app_id, version, parent):
         translator_credits=_("translator-credits"),
         version=version,
         website="https://apps.gnome.org/Music/",
-        issue_url="https://gitlab.gnome.org/GNOME/gnome-music/-/issues/new",
+        issue_url="https://gitlab.gnome.org/GNOME/gnome-music/-/issues/",
         copyright=_("© The GNOME Music Developers"),
         license_type=Gtk.License.GPL_2_0)
 
